# Table of Contents

- [retrieving-sbom-library-components-for-business-applications](<./retrieving-sbom-library-components-for-business-applications.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Retrieving SBOM Library Components for Business Applications](<./Retrieving-SBOM-Library-Components-for-Business-Applications.md>)
  - [Overview](<./Retrieving-SBOM-Library-Components-for-Business-Applications/Overview.md>)
  - [Use Cases](<./Retrieving-SBOM-Library-Components-for-Business-Applications/Use-Cases.md>)
  - [Prerequisites](<./Retrieving-SBOM-Library-Components-for-Business-Applications/Prerequisites.md>)
  - [Endpoint](<./Retrieving-SBOM-Library-Components-for-Business-Applications/Endpoint.md>)
  - [MCP Tool](<./Retrieving-SBOM-Library-Components-for-Business-Applications/MCP-Tool.md>)
  - [Related Information](<./Retrieving-SBOM-Library-Components-for-Business-Applications/Related-Information.md>)
  - [Was this page helpful?](<./Retrieving-SBOM-Library-Components-for-Business-Applications/Was-this-page-helpful.md>)
